import { useContext } from "react";
import {
  ApplicationStateContext,
  ApplicationDispatchContext
} from "../state/ApplicationContexts";

export const useAuthorizationToken = () => {
  const state = useContext(ApplicationStateContext);
  const dispatchActions = useContext(ApplicationDispatchContext);

  const getToken = () => state.security.authorization.token;
  const validateToken = () => {
    const token = getToken();
    if (!token) {
      return false;
    }

    const valid = new Date(token.validUntil) >= new Date();
    return valid;
  };

  const tokenIsValid = validateToken();

  const invalidateToken = () => {
    dispatchActions.onAuthorizationTokenChange(null);
  };

  return { getToken, validateToken, tokenIsValid, invalidateToken };
};
